@@ -1,9 +1,8 @@
 #include "fastfetch.h"
 #include "wmtheme.h"
 
-bool ffDetectWmTheme(FFinstance* instance, FFstrbuf* themeOrError)
+bool ffDetectWmTheme(FFstrbuf* themeOrError)
 {
-    FF_UNUSED(instance);
     ffStrbufAppendS(themeOrError, "Not supported on this platform");
     return false;
 }
