@@ -4,7 +4,7 @@
 
 #define FF_BIOS_MODULE_NAME "BIOS"
 
-void ffPrintBios(FFBiosOptions* options);
+bool ffPrintBios(FFBiosOptions* options);
 void ffInitBiosOptions(FFBiosOptions* options);
 void ffDestroyBiosOptions(FFBiosOptions* options);
 
