@@ -1,9 +1,11 @@
 #pragma once
 
-#include "fastfetch.h"
+#include "option.h"
 
 #define FF_DNS_MODULE_NAME "DNS"
 
-void ffPrintDNS(FFDNSOptions* options);
+bool ffPrintDNS(FFDNSOptions* options);
 void ffInitDNSOptions(FFDNSOptions* options);
 void ffDestroyDNSOptions(FFDNSOptions* options);
+
+extern FFModuleBaseInfo ffDNSModuleInfo;
