@@ -6,81 +6,64 @@
 
 #define FF_TERMINALSIZE_DISPLAY_NAME "Terminal Size"
 
-void ffPrintTerminalSize(FFTerminalSizeOptions* options)
+bool ffPrintTerminalSize(FFTerminalSizeOptions* options)
 {
     FFTerminalSizeResult result = {};
 
     if(!ffDetectTerminalSize(&result))
     {
         ffPrintError(FF_TERMINALSIZE_DISPLAY_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, "Failed to detect terminal size");
+        return false;
+    }
+
+    if(options->moduleArgs.outputFormat.length == 0)
+    {
+        ffPrintLogoAndKey(FF_TERMINALSIZE_DISPLAY_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT);
+        printf("%u columns x %u rows", result.columns, result.rows);
+
+        if (result.width != 0 && result.height != 0)
+            printf(" (%upx x %upx)", result.width, result.height);
+
+        putchar('\n');
     }
     else
     {
-        if(options->moduleArgs.outputFormat.length == 0)
-        {
-            ffPrintLogoAndKey(FF_TERMINALSIZE_DISPLAY_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT);
-            printf("%u columns x %u rows", result.columns, result.rows);
-
-            if (result.width != 0 && result.height != 0)
-                printf(" (%upx x %upx)", result.width, result.height);
-
-            putchar('\n');
-        }
-        else
-        {
-            FF_PRINT_FORMAT_CHECKED(FF_TERMINALSIZE_DISPLAY_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, ((FFformatarg[]){
-                FF_FORMAT_ARG(result.rows, "rows"),
-                FF_FORMAT_ARG(result.columns, "columns"),
-                FF_FORMAT_ARG(result.width, "width"),
-                FF_FORMAT_ARG(result.height, "height"),
-            }));
-        }
+        FF_PRINT_FORMAT_CHECKED(FF_TERMINALSIZE_DISPLAY_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, ((FFformatarg[]){
+            FF_FORMAT_ARG(result.rows, "rows"),
+            FF_FORMAT_ARG(result.columns, "columns"),
+            FF_FORMAT_ARG(result.width, "width"),
+            FF_FORMAT_ARG(result.height, "height"),
+        }));
     }
-}
-
-bool ffParseTerminalSizeCommandOptions(FFTerminalSizeOptions* options, const char* key, const char* value)
-{
-    const char* subKey = ffOptionTestPrefix(key, FF_TERMINALSIZE_MODULE_NAME);
-    if (!subKey) return false;
-    if (ffOptionParseModuleArgs(key, subKey, value, &options->moduleArgs))
-        return true;
-
-    return false;
+    return true;
 }
 
 void ffParseTerminalSizeJsonObject(FFTerminalSizeOptions* options, yyjson_val* module)
 {
-    yyjson_val *key_, *val;
+    yyjson_val *key, *val;
     size_t idx, max;
-    yyjson_obj_foreach(module, idx, max, key_, val)
+    yyjson_obj_foreach(module, idx, max, key, val)
     {
-        const char* key = yyjson_get_str(key_);
-        if(ffStrEqualsIgnCase(key, "type"))
-            continue;
-
         if (ffJsonConfigParseModuleArgs(key, val, &options->moduleArgs))
             continue;
 
-        ffPrintError(FF_TERMINALSIZE_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, "Unknown JSON key %s", key);
+        ffPrintError(FF_TERMINALSIZE_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, "Unknown JSON key %s", unsafe_yyjson_get_str(key));
     }
 }
 
 void ffGenerateTerminalSizeJsonConfig(FFTerminalSizeOptions* options, yyjson_mut_doc* doc, yyjson_mut_val* module)
 {
-    __attribute__((__cleanup__(ffDestroyTerminalSizeOptions))) FFTerminalSizeOptions defaultOptions;
-    ffInitTerminalSizeOptions(&defaultOptions);
-
-    ffJsonConfigGenerateModuleArgsConfig(doc, module, &defaultOptions.moduleArgs, &options->moduleArgs);
+    ffJsonConfigGenerateModuleArgsConfig(doc, module, &options->moduleArgs);
 }
 
-void ffGenerateTerminalSizeJsonResult(FF_MAYBE_UNUSED FFTerminalOptions* options, yyjson_mut_doc* doc, yyjson_mut_val* module)
+bool ffGenerateTerminalSizeJsonResult(FF_MAYBE_UNUSED FFTerminalSizeOptions* options, yyjson_mut_doc* doc, yyjson_mut_val* module)
 {
     FFTerminalSizeResult result;
 
     if(!ffDetectTerminalSize(&result))
     {
         yyjson_mut_obj_add_str(doc, module, "error", "Failed to detect terminal size");
-        return;
+        return false;
     }
 
     yyjson_mut_val* obj = yyjson_mut_obj_add_obj(doc, module, "result");
@@ -88,12 +71,25 @@ void ffGenerateTerminalSizeJsonResult(FF_MAYBE_UNUSED FFTerminalOptions* options
     yyjson_mut_obj_add_uint(doc, obj, "rows", result.rows);
     yyjson_mut_obj_add_uint(doc, obj, "width", result.width);
     yyjson_mut_obj_add_uint(doc, obj, "height", result.height);
+
+    return true;
 }
 
-static FFModuleBaseInfo ffModuleInfo = {
+void ffInitTerminalSizeOptions(FFTerminalSizeOptions* options)
+{
+    ffOptionInitModuleArg(&options->moduleArgs, "󰲎");
+}
+
+void ffDestroyTerminalSizeOptions(FFTerminalSizeOptions* options)
+{
+    ffOptionDestroyModuleArg(&options->moduleArgs);
+}
+
+FFModuleBaseInfo ffTerminalSizeModuleInfo = {
     .name = FF_TERMINALSIZE_MODULE_NAME,
     .description = "Print current terminal size",
-    .parseCommandOptions = (void*) ffParseTerminalSizeCommandOptions,
+    .initOptions = (void*) ffInitTerminalSizeOptions,
+    .destroyOptions = (void*) ffDestroyTerminalSizeOptions,
     .parseJsonObject = (void*) ffParseTerminalSizeJsonObject,
     .printModule = (void*) ffPrintTerminalSize,
     .generateJsonResult = (void*) ffGenerateTerminalSizeJsonResult,
@@ -105,14 +101,3 @@ static FFModuleBaseInfo ffModuleInfo = {
         {"Terminal height (in pixels)", "height"},
     })),
 };
-
-void ffInitTerminalSizeOptions(FFTerminalSizeOptions* options)
-{
-    options->moduleInfo = ffModuleInfo;
-    ffOptionInitModuleArg(&options->moduleArgs, "󰲎");
-}
-
-void ffDestroyTerminalSizeOptions(FFTerminalSizeOptions* options)
-{
-    ffOptionDestroyModuleArg(&options->moduleArgs);
-}
