@@ -4,7 +4,7 @@
 
 #define FF_VULKAN_MODULE_NAME "Vulkan"
 
-void ffPrintVulkan(FFVulkanOptions* options);
+bool ffPrintVulkan(FFVulkanOptions* options);
 void ffInitVulkanOptions(FFVulkanOptions* options);
 void ffDestroyVulkanOptions(FFVulkanOptions* options);
 
