@@ -720,6 +720,144 @@ int main(void)
         ffStrbufDestroy(&strbuf);
     }
 
+    {
+        ffStrbufAppendSInt(&strbuf, 1234567890);
+        VERIFY(ffStrbufEqualS(&strbuf, "1234567890"));
+
+        ffStrbufClear(&strbuf);
+        ffStrbufAppendSInt(&strbuf, -1234567890);
+        VERIFY(ffStrbufEqualS(&strbuf, "-1234567890"));
+
+        ffStrbufClear(&strbuf);
+        ffStrbufAppendSInt(&strbuf, 0);
+        VERIFY(ffStrbufEqualS(&strbuf, "0"));
+
+        ffStrbufClear(&strbuf);
+        ffStrbufAppendUInt(&strbuf, 1234567890);
+        VERIFY(ffStrbufEqualS(&strbuf, "1234567890"));
+
+        ffStrbufClear(&strbuf);
+        ffStrbufAppendUInt(&strbuf, 0);
+        VERIFY(ffStrbufEqualS(&strbuf, "0"));
+
+        ffStrbufDestroy(&strbuf);
+    }
+
+    {
+        ffStrbufAppendDouble(&strbuf, 120.0, 0);
+        VERIFY(ffStrbufEqualS(&strbuf, "120"));
+
+        ffStrbufClear(&strbuf);
+        ffStrbufAppendDouble(&strbuf, 120.0, 1);
+        VERIFY(ffStrbufEqualS(&strbuf, "120.0"));
+
+        ffStrbufClear(&strbuf);
+        ffStrbufAppendDouble(&strbuf, 120.0, 5);
+        VERIFY(ffStrbufEqualS(&strbuf, "120.00000"));
+
+        ffStrbufClear(&strbuf);
+        ffStrbufAppendDouble(&strbuf, 120.123456789, 5);
+        VERIFY(ffStrbufEqualS(&strbuf, "120.12346"));
+
+        ffStrbufClear(&strbuf);
+        ffStrbufAppendDouble(&strbuf, 120.888888, 0);
+        VERIFY(ffStrbufEqualS(&strbuf, "121"));
+
+        ffStrbufClear(&strbuf);
+        ffStrbufAppendDouble(&strbuf, 120.999999, 2);
+        VERIFY(ffStrbufEqualS(&strbuf, "121.00"));
+
+        ffStrbufClear(&strbuf);
+        ffStrbufAppendDouble(&strbuf, 120.123456789, 0);
+        VERIFY(ffStrbufEqualS(&strbuf, "120"));
+
+        ffStrbufClear(&strbuf);
+        ffStrbufAppendDouble(&strbuf, 120.123456789, -1);
+        VERIFY(ffStrbufEqualS(&strbuf, "120.123456789"));
+
+        ffStrbufClear(&strbuf);
+        ffStrbufAppendDouble(&strbuf, 120.123, 5);
+        VERIFY(ffStrbufEqualS(&strbuf, "120.12300"));
+
+        ffStrbufClear(&strbuf);
+        ffStrbufAppendDouble(&strbuf, -120.0, 0);
+        VERIFY(ffStrbufEqualS(&strbuf, "-120"));
+
+        ffStrbufClear(&strbuf);
+        ffStrbufAppendDouble(&strbuf, -120.0, 1);
+        VERIFY(ffStrbufEqualS(&strbuf, "-120.0"));
+
+        ffStrbufClear(&strbuf);
+        ffStrbufAppendDouble(&strbuf, -120.0, 5);
+        VERIFY(ffStrbufEqualS(&strbuf, "-120.00000"));
+
+        ffStrbufClear(&strbuf);
+        ffStrbufAppendDouble(&strbuf, -120.123456789, 5);
+        VERIFY(ffStrbufEqualS(&strbuf, "-120.12346"));
+
+        ffStrbufClear(&strbuf);
+        ffStrbufAppendDouble(&strbuf, -120.123456789, 0);
+        VERIFY(ffStrbufEqualS(&strbuf, "-120"));
+
+        ffStrbufClear(&strbuf);
+        ffStrbufAppendDouble(&strbuf, -120.123456789, -1);
+        VERIFY(ffStrbufEqualS(&strbuf, "-120.123456789"));
+
+        ffStrbufClear(&strbuf);
+        ffStrbufAppendDouble(&strbuf, -120.123, 5);
+        VERIFY(ffStrbufEqualS(&strbuf, "-120.12300"));
+
+        ffStrbufClear(&strbuf);
+        ffStrbufAppendDouble(&strbuf, -120.888888, 0);
+        VERIFY(ffStrbufEqualS(&strbuf, "-121"));
+
+        ffStrbufClear(&strbuf);
+        ffStrbufAppendDouble(&strbuf, -120.999999, 2);
+        VERIFY(ffStrbufEqualS(&strbuf, "-121.00"));
+
+        ffStrbufClear(&strbuf);
+        ffStrbufAppendDouble(&strbuf, 1.2345e50, 1);
+        VERIFY(ffStrbufEqualS(&strbuf, "1.2345e50"));
+
+        ffStrbufClear(&strbuf);
+        ffStrbufAppendDouble(&strbuf, -1.2345e50, 1);
+        VERIFY(ffStrbufEqualS(&strbuf, "-1.2345e50"));
+
+        ffStrbufClear(&strbuf);
+        ffStrbufAppendDouble(&strbuf, 1.2345e50, 0);
+        VERIFY(ffStrbufEqualS(&strbuf, "1.2345e50"));
+
+        ffStrbufClear(&strbuf);
+        ffStrbufAppendDouble(&strbuf, -1.2345e50, 0);
+        VERIFY(ffStrbufEqualS(&strbuf, "-1.2345e50"));
+
+        ffStrbufClear(&strbuf);
+        ffStrbufAppendDouble(&strbuf, 1.2345e50, -1);
+        VERIFY(ffStrbufEqualS(&strbuf, "1.2345e50"));
+
+        ffStrbufClear(&strbuf);
+        ffStrbufAppendDouble(&strbuf, -1.2345e50, -1);
+        VERIFY(ffStrbufEqualS(&strbuf, "-1.2345e50"));
+
+        ffStrbufClear(&strbuf);
+        ffStrbufAppendDouble(&strbuf, 1.2345e20, 1);
+        VERIFY(ffStrbufEqualS(&strbuf, "123450000000000000000.0"));
+
+        ffStrbufClear(&strbuf);
+        ffStrbufAppendDouble(&strbuf, -1.2345e20, 1);
+        VERIFY(ffStrbufEqualS(&strbuf, "-123450000000000000000.0"));
+
+        ffStrbufClear(&strbuf);
+        ffStrbufAppendDouble(&strbuf, +0.0, 0);
+        VERIFY(ffStrbufEqualS(&strbuf, "0"));
+
+        ffStrbufClear(&strbuf);
+        ffStrbufAppendDouble(&strbuf, -0.0, 0);
+        VERIFY(ffStrbufEqualS(&strbuf, "-0"));
+
+        ffStrbufDestroy(&strbuf);
+    }
+
     //Success
     puts("\e[32mAll tests passed!" FASTFETCH_TEXT_MODIFIER_RESET);
 }
